"""The future strategy implements getting data from LibreTime."""

from datetime import datetime


def get_show(future: datetime) -> str:  # pragma: no cover
    """Return the currently runing shows slug from LibreTime."""
    raise NotImplementedError("future")
